@@ -8,12 +8,12 @@ import uuid
 import weakref
 from typing import Awaitable, Callable, Final, Literal, Optional, Set, Type, TypeAlias, Union
 
-import aioredis
-import aioredis.client
 from aiohttp import web
 from aiohttp_sse import sse_response
+from redis.asyncio import Redis
+from redis.asyncio.client import Pipeline
 
-from . import redis
+from . import redis_helper
 from .events import (
     BgtaskCancelledEvent,
     BgtaskDoneEvent,
@@ -26,7 +26,7 @@ from .logging import BraceStyleAdapter
 from .types import AgentId, Sentinel
 
 sentinel: Final = Sentinel.TOKEN
-log = BraceStyleAdapter(logging.getLogger("ai.backend.manager.background"))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 TaskResult = Literal["bgtask_done", "bgtask_cancelled", "bgtask_failed"]
 BgtaskEvents: TypeAlias = (
     BgtaskUpdatedEvent | BgtaskDoneEvent | BgtaskCancelledEvent | BgtaskFailedEvent
@@ -60,10 +60,10 @@ class ProgressReporter:
         current, total = self.current_progress, self.total_progress
         redis_producer = self.event_producer.redis_client
 
-        def _pipe_builder(r: aioredis.Redis) -> aioredis.client.Pipeline:
+        async def _pipe_builder(r: Redis) -> Pipeline:
             pipe = r.pipeline(transaction=False)
             tracker_key = f"bgtask.{self.task_id}"
-            pipe.hset(
+            await pipe.hset(
                 tracker_key,
                 mapping={
                     "current": str(current),
@@ -72,10 +72,10 @@ class ProgressReporter:
                     "last_update": str(time.time()),
                 },
             )
-            pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
+            await pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
             return pipe
 
-        await redis.execute(redis_producer, _pipe_builder)
+        await redis_helper.execute(redis_producer, _pipe_builder)
         await self.event_producer.produce_event(
             BgtaskUpdatedEvent(
                 self.task_id,
@@ -128,7 +128,7 @@ class BackgroundTaskManager:
         """
         tracker_key = f"bgtask.{task_id}"
         redis_producer = self.event_producer.redis_client
-        task_info = await redis.execute(
+        task_info = await redis_helper.execute(
             redis_producer,
             lambda r: r.hgetall(tracker_key),
             encoding="utf-8",
@@ -194,15 +194,16 @@ class BackgroundTaskManager:
         self,
         func: BackgroundTask,
         name: str = None,
+        **kwargs,
     ) -> uuid.UUID:
         task_id = uuid.uuid4()
         redis_producer = self.event_producer.redis_client
 
-        def _pipe_builder(r: aioredis.Redis) -> aioredis.client.Pipeline:
+        async def _pipe_builder(r: Redis) -> Pipeline:
             pipe = r.pipeline()
             tracker_key = f"bgtask.{task_id}"
             now = str(time.time())
-            pipe.hset(
+            await pipe.hset(
                 tracker_key,
                 mapping={
                     "status": "started",
@@ -213,12 +214,12 @@ class BackgroundTaskManager:
                     "last_update": now,
                 },
             )
-            pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
+            await pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
             return pipe
 
-        await redis.execute(redis_producer, _pipe_builder)
+        await redis_helper.execute(redis_producer, _pipe_builder)
 
-        task = asyncio.create_task(self._wrapper_task(func, task_id, name))
+        task = asyncio.create_task(self._wrapper_task(func, task_id, name, **kwargs))
         self.ongoing_tasks.add(task)
         return task_id
 
@@ -227,6 +228,7 @@ class BackgroundTaskManager:
         func: BackgroundTask,
         task_id: uuid.UUID,
         task_name: Optional[str],
+        **kwargs,
     ) -> None:
         task_result: TaskResult
         reporter = ProgressReporter(self.event_producer, task_id)
@@ -235,7 +237,7 @@ class BackgroundTaskManager:
             BgtaskFailedEvent
         ] = BgtaskDoneEvent
         try:
-            message = await func(reporter) or ""
+            message = await func(reporter, **kwargs) or ""
             task_result = "bgtask_done"
         except asyncio.CancelledError:
             task_result = "bgtask_cancelled"
@@ -248,21 +250,21 @@ class BackgroundTaskManager:
         finally:
             redis_producer = self.event_producer.redis_client
 
-            async def _pipe_builder(r: aioredis.Redis):
+            async def _pipe_builder(r: Redis):
                 pipe = r.pipeline()
                 tracker_key = f"bgtask.{task_id}"
-                pipe.hset(
+                await pipe.hset(
                     tracker_key,
                     mapping={
-                        "status": task_result[7:],  # strip "bgtask_"
+                        "status": task_result[len("bgtask_") :],  # strip "bgtask_"
                         "msg": message,
                         "last_update": str(time.time()),
                     },
                 )
-                pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
-                await pipe.execute()
+                await pipe.expire(tracker_key, MAX_BGTASK_ARCHIVE_PERIOD)
+                return pipe
 
-            await redis.execute(redis_producer, _pipe_builder)
+            await redis_helper.execute(redis_producer, _pipe_builder)
             await self.event_producer.produce_event(
                 event_cls(
                     task_id,
