@@ -51,7 +51,7 @@ __all__ = (
 
 Event = namedtuple("Event", "key event value")
 
-log = BraceStyleAdapter(logging.getLogger(__name__))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 
 
 class ConfigScopes(enum.Enum):
@@ -100,7 +100,6 @@ R = TypeVar("R")
 
 
 class AsyncEtcd:
-
     etcd: EtcdClient
 
     _creds: Optional[EtcdCredential]
