@@ -56,7 +56,7 @@ __all__ = (
     "EventProducer",
 )
 
-log = BraceStyleAdapter(logging.getLogger("ai.backend.common.events"))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 
 PTGExceptionHandler: TypeAlias = Callable[
     [Type[Exception], Exception, TracebackType], Awaitable[None]
@@ -64,8 +64,7 @@ PTGExceptionHandler: TypeAlias = Callable[
 
 
 class AbstractEvent(metaclass=abc.ABCMeta):
-
-    # derivatives shoudld define the fields.
+    # derivatives should define the fields.
 
     name: ClassVar[str] = "undefined"
 
@@ -129,7 +128,6 @@ class DoTerminateSessionEvent(AbstractEvent):
 
 @attrs.define(slots=True, frozen=True)
 class GenericAgentEventArgs:
-
     reason: str = attrs.field(default="")
 
     def serialize(self) -> tuple:
