@@ -10,7 +10,7 @@ import attrs
 from ..logging_utils import BraceStyleAdapter
 from . import AbstractPlugin, BasePluginContext
 
-log = BraceStyleAdapter(logging.getLogger(__name__))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 
 __all__ = (
     "HookHandler",
